@@ -95,9 +95,7 @@ class ConsoleCodesConverter(BaseConverter):
             self.end = end
 
         def tryParse(self, code):
-            try:
-                code = ord(code)
-            except Exception as e:
+            if not isinstance(code, int):
                 return False
             return self.begin <= code <= self.end
 
@@ -177,7 +175,6 @@ class ConsoleCodesConverter(BaseConverter):
                 if m:
                     codes = SaveableIterator(ctrl.split(';'))
                     for code in codes:
-
                         code = int(code or '0')
                         res = self.evaluteGram(code, codes)
                         if res:
@@ -190,7 +187,7 @@ class ConsoleCodesConverter(BaseConverter):
                     yield self.output.outputText(txt)
             yield self.output.endText()
 
-        return "".join((x for x in generator() if x))
+        return "".join(x for x in generator() if x)
 
     def detect(self, s):
         """
