@@ -26,7 +26,7 @@ from itertools import groupby
 from collections import defaultdict
 
 
-class DbPkg(object):
+class DbPkg():
     db_path = 'var/db/pkg'
 
 
@@ -40,7 +40,7 @@ class ContentsError(Exception):
     pass
 
 
-class ContentsFormat(object):
+class ContentsFormat():
     """
     Функция для конвертации данных из CONTENT в словарь и обратно
     """
@@ -97,8 +97,8 @@ class PkgContents(ContentsFormat):
         """
         Re-read contents
         """
-        self.content = dict(filter(None, map(self._identifyLine,
-                                             readLinesFile(self.contentFile))))
+        self.content = dict((x for x 
+            in map(self._identifyLine, readLinesFile(self.contentFile) ) if x))
 
     def writeContents(self):
         """
@@ -125,7 +125,7 @@ class PkgContents(ContentsFormat):
         filename = self.reCfg.sub("/", filename)
         self.content[filename] = {'type': 'obj',
                                   'md5': hashlib.md5(
-                                      readFile(newfilename)).hexdigest(),
+                                      readFile(newfilename, binary=True)).hexdigest(),
                                   'mtime': str(
                                       int(os.stat(newfilename).st_mtime))}
 
@@ -192,17 +192,17 @@ def checkReserved(fileName, contentFile):
     Check contents with newContent
     """
     TYPE, FILENAME, MD5, MTIME = 0, 1, 2, 3
-    obj = filter(lambda x: x[1] == fileName,
-                 map(lambda x: x.split(' '),
-                     filter(lambda x: x.startswith('obj'),
-                            readLinesFile(contentFile))))
+    obj = [x for x in [y.split(' ') for y 
+            in readLinesFile(contentFile) 
+            if y.startswith('obj')] 
+        if x[1] == fileName]
     # if pkg not content filename
     if not obj:
         return True
     # if file is not exists
     if not path.exists(fileName):
         return True
-    contentMD5 = hashlib.md5(readFile(fileName)).hexdigest().strip()
+    contentMD5 = hashlib.md5(readFile(fileName, binary=True)).hexdigest().strip()
     configMD5 = obj[0][MD5].strip()
     # if content was not changed
     if contentMD5 == configMD5:
@@ -222,10 +222,9 @@ def checkContents(pkg, fileName, prefix='/', reservedFile=None):
         shortName = fileName
 
     TYPE, FILENAME, MD5, MTIME = 0, 1, 2, 3
-    obj = filter(lambda x: x[1] == shortName,
-                 map(lambda x: x.split(' '),
-                     filter(lambda x: x.startswith('obj'),
-                            readLinesFile(contentFile))))
+    obj = [x for x in (y.split(' ') for y 
+            in readLinesFile(contentFile) if y.startswith('obj')) 
+            if x[1] == shortName]
     # if pkg not content filename
     if not obj:
         # for using reserved -CONTENTS file on postinst
@@ -240,7 +239,7 @@ def checkContents(pkg, fileName, prefix='/', reservedFile=None):
             return True
         else:
             return False
-    contentMD5 = hashlib.md5(readFile(fileName)).hexdigest().strip()
+    contentMD5 = hashlib.md5(readFile(fileName, binary=True)).hexdigest().strip()
     configMD5 = obj[0][MD5].strip()
     # if content was not changed
     if contentMD5 == configMD5:
@@ -253,13 +252,12 @@ def getCfgFiles(protected_dirs=('/etc',), prefix='/'):
     Get protected cfg files
     """
     reCfg = re.compile(r"/\._cfg\d{4}_", re.S)
-    findParams = ["find"] + map(lambda x: pathJoin(prefix, x),
-                                protected_dirs) + [
+    findParams = ["find"] + [pathJoin(prefix, x) for x in protected_dirs] + [
                      "-name", "._cfg????_*", "!", "-name", ".*~", "!", "-iname",
                      ".*.bak", "-printf", r"%T@ %p\n"]
     mapCfg = {}
-    for filetime, sep, filename in map(lambda x: x.partition(' '),
-                                       filter(None, process(*findParams))):
+    for filetime, sep, filename in (x.partition(' ') for x 
+            in (y for y in process(*findParams) if y)):
         origFilename = reCfg.sub(r'/', filename)
         if not origFilename in mapCfg:
             mapCfg[origFilename] = []
@@ -273,19 +271,19 @@ def fillContents(allContent, protected, prefix='/'):
     """
     dbPath = pathJoin(prefix, DbPkg.db_path)
     for contentFile in glob.glob(dbPath + "/*/*/CONTENTS"):
-        for objFile in filter(lambda x: x.startswith('obj '),
-                              readLinesFile(contentFile)):
+        for objFile in (x for x 
+                in readLinesFile(contentFile) if x.startswith('obj ')):
             res = PkgContents.reObj.search(objFile.strip())
             if res:
                 fn = res.groupdict()['filename']
-                if filter(lambda x: fn.startswith(x), protected):
+                if [x for x in protected if fn.startswith(x)]:
                     pkg = reVerSplit.search(os.path.dirname(contentFile))
                     if pkg:
                         pkg = "%s/%s" % (pkg.groups()[:2])
                         allContent[fn] = pkg
 
 
-class FileOwners(object):
+class FileOwners():
     """
     Объект позволяющий определить какому пакету принадлежит указанный файл
     """
@@ -307,7 +305,7 @@ class FileOwners(object):
             fn_info = self.file_owners[fn][0]
             if not path.islink(fn):
                 if path.isfile(fn):
-                    system_md5 = hashlib.md5(readFile(fn)).hexdigest().strip()
+                    system_md5 = hashlib.md5(readFile(fn, binary=True)).hexdigest().strip()
                     if system_md5 != fn_info.get('md5', ''):
                         yield fn
             else:
@@ -357,10 +355,11 @@ class FileOwnersRestricted(FileOwners):
 
     def __init__(self, prefix='/', files=()):
         self.files = list(files)
-        super(FileOwnersRestricted, self).__init__(prefix)
+        super().__init__(prefix)
 
     def content_files(self):
         if self.files:
+            #TODO could be bugged
             searcher = re.compile("|".join(" %s[\n ]" % x for x in self.files))
             for fn in glob.glob(path.join(self.db_path, '*/*/CONTENTS')):
                 if searcher.search(readFile(fn)):
