@@ -26,7 +26,7 @@ setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 def get_edid_data():
     for fn in device.sysfs.glob(device.sysfs.Path.Drm,"*/edid"):
-        ediddata = device.sysfs.read(fn)
+        ediddata = device.sysfs.read(fn, binary=True)
         if ediddata:
             return ediddata
     return None
